package maxflow;

import org.graphstream.graph.Edge;
import org.graphstream.graph.Graph;
import org.graphstream.graph.Node;
import org.graphstream.graph.implementations.SingleGraph;
import org.graphstream.stream.GraphParseException;

import java.io.IOException;
import java.util.Arrays;

public class TestMaxFlowGrumes {

    public static void main(String[] args) throws IOException, GraphParseException {
        Graph g = new SingleGraph("test");
		String[] restrictedEdges = new String[]{"e1","e2","e3","e4","e5","e6","e7"};
		String[] restrictedNodes = new String[]{"1_2","3","4_5","6","alpha_beta","gamma","sigma", "s","t"};

        g.addAttribute("ui.stabilization-limit");
        g.addAttribute("ui.antialias");
        g.read("data/grumes_model_2.dgs");
        g.display();

        MaxFlow mf = new MaxFlow();
        mf.setCapacityAttribute("cap");
        mf.init(g);
        mf.setSource(g.getNode("s"));
        mf.setSink(g.getNode("t"));
        mf.compute();

        System.out.println(mf.getFlow());
        for (Edge e : g.getEachEdge()) {
            double flow = mf.getFlow(e);
            double cap = mf.getCapacity(e);
            if(!Arrays.asList(restrictedEdges).contains(e.getId()))
				e.addAttribute("ui.label", e.getId() + " (" + flow + " / " + cap +")");
            else
				e.addAttribute("ui.label", flow + " / " + cap );
            if (cap == flow) e.addAttribute("ui.style", "fill-color: red;");
        }
        for (Node n : g.getEachNode()) {
            String id = n.getId();
            if (Arrays.asList(restrictedNodes).contains(id)) {
                n.addAttribute("ui.label", id);
            }
        }
    }

}
